;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "org-re-reveal" "20250821.1332"
  "Org export to reveal.js presentations."
  '((emacs   "24.4")
    (org     "8.3")
    (htmlize "1.34"))
  :url "https://gitlab.com/oer/org-re-reveal"
  :commit "ca0d49878760d7d6a044857f7be2f2ee91e166e5"
  :revdesc "ca0d49878760"
  :keywords '("tools" "outlines" "hypermedia" "slideshow" "presentation" "oer"))
